@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2015 Steven L. Scott
 
@@ -19,10 +20,10 @@
 #ifndef BOOM_JACOBIAN_CHECKER_HPP_
 #define BOOM_JACOBIAN_CHECKER_HPP_
 
-#include <memory>
 #include <functional>
-#include <TargetFun/Transformation.hpp>
-#include <numopt/NumericalDerivatives.hpp>
+#include <memory>
+#include "TargetFun/Transformation.hpp"
+#include "numopt/NumericalDerivatives.hpp"
 
 namespace BOOM {
 
@@ -44,8 +45,7 @@ namespace BOOM {
     //     analytic version match.
     JacobianChecker(
         const std::function<Vector(const Vector &)> &inverse_transformation,
-        const std::shared_ptr<Jacobian> &analytic_jacobian,
-        double epsilon);
+        const std::shared_ptr<Jacobian> &analytic_jacobian, double epsilon);
 
     // The following functions return 'true' if the analytic and
     // numeric Jacobians match, and 'false' if they don't.
@@ -83,13 +83,12 @@ namespace BOOM {
     bool check_logdet_Hessian(const Vector &new_parameterization);
 
    private:
-    std::function<Vector(const Vector &) > inverse_transformation_;
+    std::function<Vector(const Vector &)> inverse_transformation_;
     NumericJacobian numeric_jacobian_;
     std::shared_ptr<Jacobian> analytic_jacobian_;
     double epsilon_;
   };
 
-
 }  // namespace BOOM
 
-#endif //  BOOM_JACOBIAN_CHECKER_HPP_
+#endif  //  BOOM_JACOBIAN_CHECKER_HPP_
