@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2006 Steven L. Scott
 
@@ -16,63 +17,59 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/Glm/PosteriorSamplers/MnpBetaGivenSigmaSampler.hpp>
-#include <Models/Glm/MultinomialProbitModel.hpp>
-#include <distributions.hpp>
-#include <Models/ParamTypes.hpp>
+#include "Models/Glm/PosteriorSamplers/MnpBetaGivenSigmaSampler.hpp"
+#include "Models/Glm/MultinomialProbitModel.hpp"
+#include "Models/ParamTypes.hpp"
+#include "distributions.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
   typedef MnpBetaGivenSigmaSampler MBS;
   typedef MultinomialProbitModel MNP;
 
-  MBS::MnpBetaGivenSigmaSampler(MNP *Mod,
-                                Ptr<VectorParams> B,
-                                Ptr<UnivParams> K,
-                                RNG &seeding_rng)
-    : PosteriorSampler(seeding_rng),
-      mnp(Mod),
-      b(B),
-      kappa(K),
-      b0_fixed(true)
-  {}
+  MBS::MnpBetaGivenSigmaSampler(MNP *Mod, const Ptr<VectorParams> &B,
+                                const Ptr<UnivParams> &K, RNG &seeding_rng)
+      : PosteriorSampler(seeding_rng),
+        mnp(Mod),
+        b(B),
+        kappa(K),
+        b0_fixed(true) {}
 
-  MBS::MnpBetaGivenSigmaSampler(MNP *Mod,
-                                const Vector &B,
-                                double K,
+  MBS::MnpBetaGivenSigmaSampler(MNP *Mod, const Vector &B, double K,
                                 RNG &seeding_rng)
-    : PosteriorSampler(seeding_rng),
-      mnp(Mod),
-      b(new VectorParams(B)),
-      kappa(new UnivParams(K)),
-      b0_fixed(true)
-  {}
+      : PosteriorSampler(seeding_rng),
+        mnp(Mod),
+        b(new VectorParams(B)),
+        kappa(new UnivParams(K)),
+        b0_fixed(true) {}
 
-  void MBS::draw(){
+  void MBS::draw() {
     double n = mnp->n();
     double k = kappa->value();
-    const SpdMatrix & xtx(mnp->xtx());
-    SpdMatrix ivar = (xtx)*(1+k/n);
+    const SpdMatrix &xtx(mnp->xtx());
+    SpdMatrix ivar = (xtx) * (1 + k / n);
     const Vector &B(b->value());
-    Vector mean = mnp->xty() + (xtx*B)*(k/n);
+    Vector mean = mnp->xty() + (xtx * B) * (k / n);
     mean = ivar.solve(mean);
     Vector beta = rmvn_ivar(mean, ivar);
-    if(b0_fixed){
+    if (b0_fixed) {
       uint start = 0;
       uint p = mnp->subject_nvars();
-      Vector b0(beta.begin(), beta.begin()+p);
-      for(uint i=0; i<mnp->Nchoices(); ++i){
+      Vector b0(beta.begin(), beta.begin() + p);
+      for (uint i = 0; i < mnp->Nchoices(); ++i) {
         VectorView(beta, start, p) -= b0;
-    start+=p;}}
+        start += p;
+      }
+    }
     mnp->set_beta(beta);
   }
 
-  double MBS::logpri()const{
+  double MBS::logpri() const {
     double n = mnp->n();
     double k = kappa->value();
-    SpdMatrix ivar = mnp->xtx()*k/n;
+    SpdMatrix ivar = mnp->xtx() * k / n;
     const Vector &B(b->value());
     return dmvn(mnp->beta(), B, ivar, ivar.logdet(), true);
   }
-  void MBS::fix_beta0(bool yn){b0_fixed=yn;}
-}
+  void MBS::fix_beta0(bool yn) { b0_fixed = yn; }
+}  // namespace BOOM
