@@ -154,12 +154,9 @@ namespace BOOM {
   }
 
   //======================================================================
-  void SSLM::setup() { observe(observation_model_->coef_prm()); }
-
   SSLM::StateSpaceLogitModel(int xdim)
       : StateSpaceNormalMixture(xdim > 1),
         observation_model_(new BinomialLogitModel(xdim)) {
-    setup();
   }
 
   SSLM::StateSpaceLogitModel(const Vector &successes, const Vector &trials,
@@ -167,7 +164,6 @@ namespace BOOM {
                              const std::vector<bool> &observed)
       : StateSpaceNormalMixture(ncol(design_matrix)),
         observation_model_(new BinomialLogitModel(ncol(design_matrix))) {
-    setup();
     bool all_observed = observed.empty();
     if (successes.size() != trials.size() ||
         successes.size() != nrow(design_matrix) ||
@@ -251,8 +247,11 @@ namespace BOOM {
   }
 
   Vector StateSpaceLogitModel::one_step_holdout_prediction_errors(
-      RNG &rng, BinomialLogitDataImputer &data_imputer, const Vector &successes,
-      const Vector &trials, const Matrix &predictors,
+      RNG &rng,
+      BinomialLogitDataImputer &data_imputer,
+      const Vector &successes,
+      const Vector &trials,
+      const Matrix &predictors,
       const Vector &final_state) {
     if (nrow(predictors) != successes.size() ||
         trials.size() != successes.size()) {
@@ -262,23 +261,24 @@ namespace BOOM {
     }
     Vector ans(successes.size());
     int t0 = dat().size();
-    ScalarKalmanStorage ks(state_dimension());
-    ks.a = *state_transition_matrix(t0 - 1) * final_state;
-    ks.P = SpdMatrix(state_variance_matrix(t0 - 1)->dense());
 
-    // This function differs from the Gaussian case because the
-    // response is on the binomial scale, and the state model is on
-    // the logit scale.  Because of the nonlinearity, we need to
-    // incorporate the uncertainty about the forecast in the
-    // prediction for the observation.  We do this by imputing the
-    // latent logit and its mixture indicator for each observation.
+    Kalman::ScalarMarginalDistribution marg(this, nullptr, 0);
+    marg.set_state_mean(*state_transition_matrix(t0 - 1) * final_state);
+    marg.set_state_variance(SpdMatrix(state_variance_matrix(t0 - 1)->dense()));
+
+    // This function differs from the Gaussian case because the response is on
+    // the binomial scale, and the state model is on the logit scale.  Because
+    // of the nonlinearity, we need to incorporate the uncertainty about the
+    // forecast in the prediction for the observation.  We do this by imputing
+    // the latent logit and its mixture indicator for each observation.
+    //
     // The strategy is (for each observation)
     //   1) simulate next state.
     //   2) simulate w_t given state
     //   3) kalman update state given w_t.
     for (int t = 0; t < ans.size(); ++t) {
       bool missing = false;
-      Vector state = rmvn(ks.a, ks.P);
+      Vector state = rmvn_mt(rng, marg.state_mean(), marg.state_variance());
 
       double state_contribution = observation_matrix(t + t0).dot(state);
       double regression_contribution =
@@ -287,26 +287,23 @@ namespace BOOM {
       double prediction = trials[t] * plogis(mu);
       ans[t] = successes[t] - prediction;
 
-      // ans[t] is a random draw of the one step ahead prediction
-      // error at time t0+t given observed data to time t0+t-1.  We
-      // now proceed with the steps needed to update the Kalman filter
-      // so we can compute ans[t+1].
+      // ans[t] is a random draw of the one step ahead prediction error at time
+      // t0+t given observed data to time t0+t-1.  We now proceed with the steps
+      // needed to update the Kalman filter so we can compute ans[t+1].
 
       double precision_weighted_sum, total_precision;
       std::tie(precision_weighted_sum, total_precision) =
           data_imputer.impute(rng, trials[t], successes[t], mu);
       double latent_observation = precision_weighted_sum / total_precision;
       double latent_variance = 1.0 / total_precision;
-
-      // The latent state was drawn from its predictive distribution
-      // given Y[t0 + t -1] and used to impute the latent data for
-      // y[t0+t].  That latent data is now used to update the Kalman
-      // filter for the next time period.  It is important that we
-      // discard the imputed state at this point.
-      sparse_scalar_kalman_update(
-          latent_observation - regression_contribution, ks.a, ks.P, ks.K, ks.F,
-          ks.v, missing, observation_matrix(t + t0), latent_variance,
-          *state_transition_matrix(t + t0), *state_variance_matrix(t + t0));
+      double weight = latent_variance / Constants::pi_squared_over_3;
+      
+      // The latent state was drawn from its predictive distribution given Y[t0
+      // + t -1] and used to impute the latent data for y[t0+t].  That latent
+      // data is now used to update the Kalman filter for the next time period.
+      // It is important that we discard the imputed state at this point.
+      marg.update(latent_observation - regression_contribution,
+                  missing, t + t0, weight);
     }
     return ans;
   }
